@@ -20,9 +20,10 @@ import (
 	kubeclient "k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/util/workqueue"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
+	configv1informers "github.com/openshift/client-go/config/informers/externalversions/config/v1"
 	imageregistryclient "github.com/openshift/client-go/imageregistry/clientset/versioned"
 	imageregistryinformers "github.com/openshift/client-go/imageregistry/informers/externalversions"
 
@@ -50,6 +51,7 @@ func NewImagePrunerController(
 	imageregistryClient imageregistryclient.Interface,
 	kubeInformerFactory kubeinformers.SharedInformerFactory,
 	regopInformerFactory imageregistryinformers.SharedInformerFactory,
+	imageConfigInformer configv1informers.ImageInformer,
 ) *ImagePrunerController {
 	listers := &regopclient.ImagePrunerControllerListers{}
 	clients := &regopclient.Clients{}
@@ -111,6 +113,10 @@ func NewImagePrunerController(
 			c.listers.ConfigMaps = informer.Lister().ConfigMaps(defaults.ImageRegistryOperatorNamespace)
 			return informer.Informer()
 		},
+		func() cache.SharedIndexInformer {
+			c.listers.ImageConfigs = imageConfigInformer.Lister()
+			return imageConfigInformer.Informer()
+		},
 	} {
 		informer := ctor()
 		informer.AddEventHandler(c.handler())
